from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import ON, Boolean


@abaqus_class_doc
class OptimizationTaskDisplayOptions:
    """The OptimizationTaskDisplayOptions object stores settings that specify how assemblies are to be displayed
    in a particular viewport when session.viewports[name].assemblyDisplay.optimizationTasks=ON The
    OptimizationTaskDisplayOptions object has no constructor. When you create a new viewport, the settings are
    copied from the current viewport.

    .. note::
        This object can be accessed by::

            session.viewports[name].assemblyDisplay.optimizationTaskOptions
            session.viewports[name].layers[name].assemblyDisplay.optimizationTaskOptions
    """

    @abaqus_method_doc
    def setValues(self, topologyTask: Boolean = ON, shapeTask: Boolean = ON):
        """This method modifies the OptimizationTaskDisplayOptions object.

        Parameters
        ----------
        topologyTask
            A Boolean specifying whether topology task symbols are shown. The default value is ON.
        shapeTask
            A Boolean specifying whether shape task symbols are shown. The default value is ON.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from typing import Sequence, Union

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class Path:
    """The Path object defines a line through your model by specifying a series of nodes or points.

    .. note::
        This object can be accessed by::

            import visualization
            session.paths[name]
    """

    #: If **type** = NODE_LIST, **coordinates** is a sequence of tuples of three Floats. This can be
    #: used as the value for the **expression** argument when creating a Path object of **type** =
    #: POINT_LIST.
    coordinates: list[Sequence[float]] = []

    #: A String specifying the repository key.
    name: str

    #: A SymbolicConstant specifying the type of path being created. Possible values are
    #: NODE_LIST, POINT_LIST, EDGE_LIST, CIRCUMFERENTIAL, and RADIAL.
    type: SymbolicConstant

    #: A sequence specifying the nodes or points that make up the path. The definition of the
    #: path expression depends on the **type** argument.
    #:
    #: - If **type** = NODE_LIST, **expression** must be a sequence of sequences. Each inner sequence
    #:   contains two items, the first item is a String specifying the name of a part instance,
    #:   and the second item can be either a sequence of Ints or a sequence of Strings, each
    #:   specifying a range of Ints.
    #: - If **type** = POINT_LIST, **expression** must be a sequence of tuples of three Floats,
    #:   specifying the coordinates of each point.
    #: - If **type** = EDGE_LIST, **expression** must be a sequence of sequences. Each inner sequence
    #:   contains two items, the first item is a String specifying the name of the part instance,
    #:   and the second item is a sequence of tuples of four Ints that uniquely identify an
    #:   element edge. The four Ints are:
    #:
    #:   1. The element label.
    #:   2. The element face index (one-based).
    #:   3. The face edge index (one-based).
    #:   4. The edge direction. A positive number specifies that the edge direction runs from the
    #:      edge start node to the edge end node. A negative number specifies the opposite.
    #:
    # - When **type** = CIRCUMFERENTIAL or RADIAL, **expression** must be a sequence of three tuples
    #:   of three Floats, specifying the coordinates of the points used to define a coordinate
    #:   system.
    expression: tuple

    #: A SymbolicConstant specifying the method in which the circle is being defined. This
    #: argument is valid only when **type** = CIRCUMFERENTIAL or RADIAL. Possible values are
    #: ORIGIN_AXIS and POINT_ARC.When the value is ORIGIN_AXIS, the first two points in
    #: **expression** are points on the rotational axis and the third point lies on the x-axis.
    #: When the value is POINT_ARC, the three points in **expression** are points lying on the
    #: arc of the circle.
    circleDefinition: SymbolicConstant

    #: An Int specifying the number of equal segments in the path. This argument is valid only
    #: when **type** = CIRCUMFERENTIAL or RADIAL.
    numSegments: int

    #: A Float specifying the start angle of the circumferential path. This argument is valid
    #: only when **type** = CIRCUMFERENTIAL.
    startAngle: float

    #: A Float specifying the end angle of the circumferential path. This argument is valid
    #: only when **type** = CIRCUMFERENTIAL.
    endAngle: float

    #: The SymbolicConstant CIRCLE_RADIUS or a Float specifying the radius of the
    #: circumferential path. This argument is valid only when **type** = CIRCUMFERENTIAL.
    radius: Union[SymbolicConstant, float]

    #: A Float specifying the angle between the radial path and the **X** axis of the specified
    #: coordinate system. This argument is valid only when **type** = RADIAL.
    radialAngle: float

    #: The SymbolicConstant CIRCLE_RADIUS or a Float specifying the start radius of the radial
    #: path. This argument is valid only when **type** = RADIAL.
    startRadius: Union[SymbolicConstant, float]

    #: The SymbolicConstant CIRCLE_RADIUS or a Float specifying the end radius of the radial
    #: path. This argument is valid only when **type** = RADIAL.
    endRadius: Union[SymbolicConstant, float]

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        type: Literal[C.EDGE_LIST, C.POINT_LIST, C.CIRCUMFERENTIAL, C.NODE_LIST, C.RADIAL],
        expression: tuple,
        circleDefinition: Literal[C.RADIAL, C.POINT_ARC, C.CIRCUMFERENTIAL, C.ORIGIN_AXIS],
        numSegments: int,
        startAngle: float,
        endAngle: float,
        radius: Union[Literal[C.CIRCUMFERENTIAL, C.CIRCLE_RADIUS], float],
        radialAngle: float,
        startRadius: Union[Literal[C.RADIAL, C.CIRCLE_RADIUS], float],
        endRadius: Union[Literal[C.RADIAL, C.CIRCLE_RADIUS], float],
    ):
        """This method creates a Path object.

        .. note::
            This function can be accessed by::

                session.Path

        Parameters
        ----------
        name
            A String specifying the repository key.
        type
            A SymbolicConstant specifying the type of path being created. Possible values are
            NODE_LIST, POINT_LIST, EDGE_LIST, CIRCUMFERENTIAL, and RADIAL.
        expression
            A sequence specifying the nodes or points that make up the path. The definition of the
            path expression depends on the **type** argument.

            - If **type** = NODE_LIST, **expression** must be a sequence of sequences. Each inner sequence
              contains two items, the first item is a String specifying the name of a part instance,
              and the second item can be either a sequence of Ints or a sequence of Strings, each
              specifying a range of Ints.
            - If **type** = POINT_LIST, **expression** must be a sequence of tuples of three Floats,
              specifying the coordinates of each point.
            - If **type** = EDGE_LIST, **expression** must be a sequence of sequences. Each inner sequence
              contains two items, the first item is a String specifying the name of the part instance,
              and the second item is a sequence of tuples of four Ints that uniquely identify an
              element edge. The four Ints are:
              1. The element label.
              2. The element face index (one-based).
              3. The face edge index (one-based).
              4. The edge direction. A positive number specifies that the edge direction runs from the
              edge start node to the edge end node. A negative number specifies the opposite.
            - When **type** = CIRCUMFERENTIAL or RADIAL, **expression** must be a sequence of three tuples
              of three Floats, specifying the coordinates of the points used to define a coordinate
              system.
        circleDefinition
            A SymbolicConstant specifying the method in which the circle is being defined. This
            argument is valid only when **type** = CIRCUMFERENTIAL or RADIAL. Possible values are
            ORIGIN_AXIS and POINT_ARC.When the value is ORIGIN_AXIS, the first two points in
            **expression** are points on the rotational axis and the third point lies on the x-axis.
            When the value is POINT_ARC, the three points in **expression** are points lying on the
            arc of the circle.
        numSegments
            An Int specifying the number of equal segments in the path. This argument is valid only
            when **type** = CIRCUMFERENTIAL or RADIAL.
        startAngle
            A Float specifying the start angle of the circumferential path. This argument is valid
            only when **type** = CIRCUMFERENTIAL.
        endAngle
            A Float specifying the end angle of the circumferential path. This argument is valid
            only when **type** = CIRCUMFERENTIAL.
        radius
            The SymbolicConstant CIRCLE_RADIUS or a Float specifying the radius of the
            circumferential path. This argument is valid only when **type** = CIRCUMFERENTIAL.
        radialAngle
            A Float specifying the angle between the radial path and the **X** axis of the specified
            coordinate system. This argument is valid only when **type** = RADIAL.
        startRadius
            The SymbolicConstant CIRCLE_RADIUS or a Float specifying the start radius of the radial
            path. This argument is valid only when **type** = RADIAL.
        endRadius
            The SymbolicConstant CIRCLE_RADIUS or a Float specifying the end radius of the radial
            path. This argument is valid only when **type** = RADIAL.

        Returns
        -------
        Path
            A Path object.

        Raises
        ------
        ModelError, ErrorUnsupportedNodeData, ErrorUnsupportedPointData, ErrorIncorrectPathData,
        KeyError, ErrorEmptyPathName, ErrorPathNotFound, and ErrorNoOdbPathDisplay.
        ValueError
            When **type** = CIRCUMFERENTIAL or RADIAL, the three points specified in
            **expression** are collinear.
        """
        ...



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean


@abaqus_class_doc
class Cell:
    """Cells are volumetric regions of geometry.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].allInternalSets[name].cells[i]
            mdb.models[name].parts[name].allSets[name].cells[i]
            mdb.models[name].parts[name].cells[i]
            mdb.models[name].parts[name].sets[name].cells[i]
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].cells[i]
            mdb.models[name].rootAssembly.allInstances[name].sets[name].cells[i]
            mdb.models[name].rootAssembly.allInternalSets[name].cells[i]
            mdb.models[name].rootAssembly.allSets[name].cells[i]
            mdb.models[name].rootAssembly.instances[name].cells[i]
            mdb.models[name].rootAssembly.instances[name].sets[name].cells[i]
            mdb.models[name].rootAssembly.modelInstances[i].sets[name].cells[i]
            mdb.models[name].rootAssembly.sets[name].cells[i]
    """

    #: An Int specifying the index of the cell in the CellArray.
    index: int | None = None

    #: A Boolean specifying whether the cell belongs to the reference representation of the
    #: Part or Instance.
    isReferenceRep: Boolean = OFF

    #: A tuple of Floats specifying the **X**, **Y**, and **Z** coordinates of a point located on
    #: the cell.
    pointOn: float | None = None

    #: A tuple of Floats specifying the name of the feature that created this cell.
    featureName: float | None = None

    #: A tuple of Floats specifying the name of the part instance for this cell (if
    #: applicable).
    instanceName: float | None = None

    @abaqus_method_doc
    def getSize(self, printResults: Boolean = True):
        """This method returns a Float indicating the volume of the cell.

        Parameters
        ----------
        printResults
            A Boolean that determines whether a verbose output is to be printed. The default is
            True.

        Returns
        -------
        float
            A Float.
        """
        ...

    @abaqus_method_doc
    def getFaces(self):
        """This method returns a sequence consisting of the face IDs of the faces which bound the cell.

        Returns
        -------
        Sequence[int]
            A tuple of integers.
        """
        ...

    @abaqus_method_doc
    def getEdges(self):
        """This method returns a sequence consisting of the edge IDs of the edges on the cell.

        Returns
        -------
        Sequence[int]
            A tuple of integers.
        """
        ...

    @abaqus_method_doc
    def getVertices(self):
        """This method returns a sequence consisting of the vertex IDs of the vertices on the cell.

        Returns
        -------
        Sequence[int]
            A tuple of integers.
        """
        ...

    @abaqus_method_doc
    def getAdjacentCells(self):
        """This method returns an array of cell objects that share at least one face of the cell.

        Returns
        -------
        CellArray
            A CellArray object which is a sequence of Cell objects.
        """
        ...

    @abaqus_method_doc
    def getNodes(self):
        """This method returns an array of node objects that are associated with the cell.

        Returns
        -------
        MeshNodeArray
            A MeshNodeArray object which is a sequence of MeshNode objects.
        """
        ...

    @abaqus_method_doc
    def getElements(self):
        """This method returns an array of element objects that are associated with the cell.

        Returns
        -------
        MeshElementArray
            A MeshElementArray object which is a sequence of MeshElement objects.
        """
        ...

    @abaqus_method_doc
    def getCADAttributes(self):
        """This method returns an array of CAD attribute strings associated with the cell when the part was
        created from CAD data.

        Returns
        -------
        list[str]
            An array of String.
        """
        ...



from __future__ import annotations

from .FXObject import FXObject

#: Extended selection mode allows for drag-selection of ranges of items.
TREELIST_EXTENDEDSELECT: int = hash("TREELIST_EXTENDEDSELECT")

#: Single selection mode allows up to one item to be selected.
TREELIST_SINGLESELECT: int = hash("TREELIST_SINGLESELECT")

#: Browse selection mode enforces one single item to be selected at all times.
TREELIST_BROWSESELECT: int = hash("TREELIST_BROWSESELECT")

#: Multiple selection mode is used for selection of individual items.
TREELIST_MULTIPLESELECT: int = hash("TREELIST_MULTIPLESELECT")

#: Automatically select under cursor.
TREELIST_AUTOSELECT: int = hash("TREELIST_AUTOSELECT")

#: Lines shown.
TREELIST_SHOWS_LINES: int = hash("TREELIST_SHOWS_LINES")

#: Boxes to expand shown.
TREELIST_SHOWS_BOXES: int = hash("TREELIST_SHOWS_BOXES")

#: Display root boxes also.
TREELIST_ROOT_BOXES: int = hash("TREELIST_ROOT_BOXES")

#: Display check boxes.
TREELIST_CHECK_BOXES: int = hash("TREELIST_CHECK_BOXES")

#: Propagate checked state to children and parents.
TREELIST_PROPAGATE_CHECKS: int = hash("TREELIST_PROPAGATE_CHECKS")


class FXTreeItem(FXObject):
    """Tree list Item."""



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Part.Part import Part
from ..UtilityAndView.abaqusConstants import DEFAULT_MODEL, SymbolicConstant
from .Leaf import Leaf


@abaqus_class_doc
class LeafFromPartElementLabels(Leaf):
    """The LeafFromPartElementLabels object can be used whenever a Leaf object is expected as an argument. Leaf
    objects are used to specify the items in a display group. Leaf objects are constructed as temporary objects,
    which are then used as arguments to DisplayGroup commands. The LeafFromPartElementLabels object is derived
    from the Leaf object.

    .. note::
        This object can be accessed by::

            import displayGroupMdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant

    @abaqus_method_doc
    def __init__(self, part: Part, elementLabels: tuple):
        """This method creates a Leaf object from a sequence of Strings specifying element labels. Leaf objects
        specify the items in a display group.

        .. note::
            This function can be accessed by::

                LeafFromPartElementLabels

        Parameters
        ----------
        part
            A Part object.
        elementLabels
            A sequence of Strings specifying element labels.

        Returns
        -------
        LeafFromPartElementLabels
            A LeafFromPartElementLabels object.
        """
        super().__init__(DEFAULT_MODEL)



from __future__ import annotations

from .FXObject import FXObject


class AFXItemProvider(FXObject):
    """This class provides a way to supply items to widgets, such as AFXComboBox and AFXList."""

    def __init__(self, initialItems: str = "''"):
        """Constructor.

        Parameters
        ----------
        initialItems : str
            Sequence string with initial items.
        """

    def append(self, ch: str):
        """Appends a character to the item string.

        Parameters
        ----------
        ch : str
        """

    def empty(self):
        """Returns True if the item string is empty."""

    def getItems(self):
        """Returns a sequence string that contains all of the provider's items."""

    def getVersion(self):
        """Returns the version of provider's items."""

    def reset(self, sz: int = 0):
        """Clears the contents of the item string and reallocates space.

        Parameters
        ----------
        sz : int
        """

    def setItems(self, newItems: str):
        """Sets all of the providers's items, clearing any previous items first.

        Parameters
        ----------
        newItems : str
            Sequence string with new items.
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import Boolean
from .DataSet import DataSet


@abaqus_class_doc
class Behavior:
    """The Behavior object specifies the method used for calibrating a material.

    .. note::
        This object can be accessed by::

            import calibration
            mdb.models[name].calibrations[name].behaviors[name]
    """

    #: A string specifying the name of the model to which the behavior belongs.
    modelName: str = ""

    #: A string specifying the name of calibration to which the behavior belongs.
    calibrationName: str = ""

    #: A String specifying the name of the dataset containing all the raw data in the test data
    #: file. Only valid if the behavior is of type FeFpBehavior
    biAxialAllName: str = ""

    #: A String specifying the name of the dataset containing all the raw data in the test data
    #: file. Only valid if the behavior is of type FeFpBehavior
    uniAxialAllName: str = ""

    #: A String specifying the name of the new behavior.
    name: str

    #: A String specifying the type of the new Behavior. Values can be "ElasIsoBehavior",
    #: "ElasPlasIsoBehavior", "FeFpBehavior", or a user plug-in behavior type.
    typeName: str

    @abaqus_method_doc
    def __init__(self, name: str, typeName: str):
        """This method creates a Behavior object.

        .. note::
            This function can be accessed by::

                mdb.models[name].calibrations[name].Behavior

        Parameters
        ----------
        name
            A String specifying the name of the new behavior.
        typeName
            A String specifying the type of the new Behavior. Values can be "ElasIsoBehavior",
            "ElasPlasIsoBehavior", "FeFpBehavior", or a user plug-in behavior type.

        Returns
        -------
        Behavior
            A Behavior object.
        """
        ...

    @abaqus_method_doc
    def setValues(
        self,
        E: str = "",
        nu: str = "",
        ds1Name: str = "",
        ds2Name: str = "",
        materialName: str = "",
        yieldPoint: str = "",
        ultimatePoint: str = "",
        plasticPoints: str = "",
        PoissonsRatio: str = "",
        elasticModulus: str = "",
        plasticPointsRange: str = "",
        name: str = "",
        uniaxialName: str = "",
        biaxialName: str = "",
        interpolation: str = "",
        uniWeight: str = "",
        biWeight: str = "",
        uMullinsReload: str = "",
        uMullinsUnload: str = "",
        uPYieldPoint: tuple[float, float, float] = (0.0, 0.0, 0.0),
        uPermSet: str = "",
        uPrimary: str = "",
        bMullinsReload: str = "",
        bMullinsUnload: str = "",
        bPYieldPoint: tuple[float, float, float] = (0.0, 0.0, 0.0),
        bPermSet: str = "",
        bPrimary: str = "",
    ):
        """This method modifies the data for an existing behavior object.

        Parameters
        ----------
        E
            Young's modulus. Only valid if the behavior type is ElasIsoBehavior.
        nu
            Poisson's ratio. Only valid if the behavior type is ElasIsoBehavior.
        ds1Name
            The name of the first data set. Only valid if the behavior type is ElasIsoBehavior or
            ElasPlasIsoBehavior
        ds2Name
            The name of the second data set. Only valid if the behavior type is ElasIsoBehavior or
            ElasPlasIsoBehavior
        materialName
            Material Name.
        yieldPoint
            Stress/strain value for the material yield point.Only valid if the behavior type is
            ElasPlasIsoBehavior
        ultimatePoint
            Stress/strain value for the material ultimate point.Only valid if the behavior type is
            ElasPlasIsoBehavior
        plasticPoints
            Stress/strain values for the Plastic portion of material curve. Only valid if the
            behavior type is ElasPlasIsoBehavior
        PoissonsRatio
            Poisson's Ratio. Only valid if the behavior type is ElasPlasIsoBehavior
        elasticModulus
            Young's Modulus for the elastic portion of the material curve. Only valid if the
            behavior type is ElasPlasIsoBehavior
        plasticPointsRange
            Extent of the material Plastic points. Only valid if the behavior type is
            ElasPlasIsoBehavior
        name
            Name of the behavior.
        uniaxialName
            Name of the uniaxial dataset. Only valid if the behavior type is FeFpBehavior
        biaxialName
            Name of the biaxial dataset. Only valid if the behavior type is FeFpBehavior
        interpolation
            'linear' specifies linear interpolation between data points, otherwise 'logarithmic'.
            Only valid if the behavior type is FeFpBehavior
        uniWeight
            Uniaxial weight factor, uniWeight + biWeight should equal 1.0. Only valid if the
            behavior type is FeFpBehavior
        biWeight
            Biaxial weight factor, uniWeight + biWeight should equal 1.0. Only valid if the behavior
            type is FeFpBehavior
        uMullinsReload
            A List of strings, specifying names of reloading DataSet objects obtained from uniaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        uMullinsUnload
            A List of strings, specifying names of reloading DataSet objects obtained from uniaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        uPYieldPoint
            A tuple specifying the coordinates of yield point of the permanent data set. Only valid
            if the behavior is of type FeFpBehavior
        uPermSet
            A List of strings, specifying names of permanent DataSet objects obtained from uniaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        uPrimary
            A string specifying name of Primary DataSet object.Only valid if the behavior is of type
            FeFpBehavior
        bMullinsReload
            A List of strings, specifying names of reloading DataSet objects obtained from biaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        bMullinsUnload
            A List of strings, specifying names of unloading DataSet objects obtained from biaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        bPYieldPoint
            A tuple specifying the coordinates of yield point of the permanent data set. Only valid
            if the behavior is of type FeFpBehavior
        bPermSet
            A List of strings, specifying names of permanent DataSet objects obtained from biaxial
            test data. Only valid if the behavior is of type FeFpBehavior
        bPrimary
            A string specifying name of Primary DataSet object. Only valid if the behavior is of
            type FeFpBehavior
        """
        ...

    @abaqus_method_doc
    def mapToMaterial(self, materialName: str):
        """This method appends the calibration data obtained from the DataSet object to an existing material
        object. In the case of ElasIsoBehavior, it appends the young's modulus and poisson's ratio. For
        ElasPlasIsoBehavior it appends the young's modulus, poisson's ratio and Plastic points range and for
        FeFpBehavior it appends Plastic points range and Mullins effect properties.

        Parameters
        ----------
        materialName
            A String specifying the name of the existing material
        """
        ...

    @abaqus_method_doc
    def compute_E(self, dataSet: DataSet):
        """This method computes the value of young's modulus from the existing DataSet object. The method is
        only valid for ElasIsoBehavior type of behavior.

        Parameters
        ----------
        dataSet
            A DataSet object.

        Returns
        -------
        Sequence[float]
            A tuple consisting of a and b values of the regression line(y = ax + b), coefficient of
            determination(r-squared) value and the start and end-points of the line.
        """
        ...

    @abaqus_method_doc
    def compute_nu(self, dataSet: DataSet):
        """This method computes the value of Poisson's Ratio from the existing DataSet object. The method is
        only valid for ElasIsoBehavior and ElasPlasIsoBehavior type of behavior.

        Parameters
        ----------
        dataSet
            A DataSet object.

        Returns
        -------
        Sequence[float]
            A tuple consisting of a and b values of the regression line(y = ax + b), coefficient of
            determination(r-squared) value and the start and end-points of the line.
        """
        ...

    @abaqus_method_doc
    def compute_ultimatePoint(self, dataSet: DataSet):
        """This method computes the coordinates of the Ultimate point from the existing DataSet object. The
        method is only valid for ElasPlasIsoBehavior type of behavior.

        Parameters
        ----------
        dataSet
            A DataSet object.

        Returns
        -------
        Sequence[float]
            Coordinates of the ultimate point.
        """
        ...

    @abaqus_method_doc
    def compute_elasticModulus(self, yieldPoint: tuple):
        """This method computes the value of the elastic modulus from the yieldpoint value. The method is only
        valid for ElasPlasIsoBehavior type of behavior.

        Parameters
        ----------
        yieldPoint
            A tuple consisting of coordinates of the yieldpoint.

        Returns
        -------
        float
            A float specifying the value of elastic modulus.
        """
        ...

    @abaqus_method_doc
    def compute_plasticPoints(
        self,
        dataSet: DataSet,
        slider_val: str,
        start_index: str,
        end_index: str,
        yp: str = "",
    ):
        """This method extracts the coordinates of the Plastic Points. The method is only valid for
        ElasPlasIsoBehavior type of behavior.

        Parameters
        ----------
        dataSet
            A DataSet object.
        slider_val
            A float specifying the number of values to be taken.
        start_index
            A float specifying the lower limit of the range.
        end_index
            A float specifying the upper limit of the range.
        yp
            Coordinates of the yieldpoint. The default value is (0,0).

        Returns
        -------
        Sequence[tuple[float]]
            A sequence of coordinates of the Plastic points..
        """
        ...

    @abaqus_method_doc
    def xyDataDissect(self, dsName: str, modelName: str, calibrationName: str, biaxial: Boolean = True):
        """This method extracts primary, unload, reload and permanent DataSet objects from the existing DataSet
        object.The method is only valid for FeFpBehavior type of behavior.

        Parameters
        ----------
        dsName
            A string specifying the name of the uniaxial/biaxial test dataset.
        modelName
            A string specifying the name of the model to which the calibration behavior belongs.
        calibrationName
            A string specifying the name of the Calibration object to which the behavior belongs.
        biaxial
            A boolean specifying whether the test data is biaxial or uniaxial. The default value is
            True.

        Returns
        -------
        Sequence[str]
            A sequence of strings specifying names of the DataSet objects containing loading,
            unloading, reloading and primary datasets.
        """
        ...
